"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.dataSource = exports.repositories = exports.AppDataSource = void 0;
const config_1 = require("../config");
const device_1 = require("./repositories/device");
const concreteDevice_1 = require("./repositories/device/concreteDevice");
const deviceGroup_1 = require("./repositories/device/deviceGroup");
const deviceOverview_1 = require("./repositories/device/deviceOverview");
const instantiableBrowserDevice_1 = require("./repositories/device/instantiableBrowserDevice");
const instantiableCloudDevice_1 = require("./repositories/device/instantiableCloudDevice");
const peerconnection_1 = require("./repositories/peerconnection");
const service_common_1 = require("@crosslab/service-common");
class ApplicationDataSource extends service_common_1.AbstractApplicationDataSource {
    createRepositories() {
        const deviceOverviewRepository = new deviceOverview_1.DeviceOverviewRepository();
        const concreteDeviceRepository = new concreteDevice_1.ConcreteDeviceRepository();
        const deviceGroupRepository = new deviceGroup_1.DeviceGroupRepository();
        const instantiableBrowserDeviceRepository = new instantiableBrowserDevice_1.InstantiableBrowserDeviceRepository();
        const instantiableCloudDeviceRepository = new instantiableCloudDevice_1.InstantiableCloudDeviceRepository();
        const deviceRepository = new device_1.DeviceRepository();
        const peerconnectionRepository = new peerconnection_1.PeerconnectionRepository();
        concreteDeviceRepository.setDependencies({
            deviceOverview: deviceOverviewRepository,
        });
        deviceGroupRepository.setDependencies({
            deviceOverview: deviceOverviewRepository,
        });
        instantiableBrowserDeviceRepository.setDependencies({
            deviceOverview: deviceOverviewRepository,
        });
        instantiableCloudDeviceRepository.setDependencies({
            deviceOverview: deviceOverviewRepository,
        });
        deviceRepository.setDependencies({
            concreteDevice: concreteDeviceRepository,
            deviceGroup: deviceGroupRepository,
            deviceOverview: deviceOverviewRepository,
            instantiableBrowserDevice: instantiableBrowserDeviceRepository,
            instantiableCloudDevice: instantiableCloudDeviceRepository,
        });
        return {
            device: deviceRepository,
            deviceOverview: deviceOverviewRepository,
            concreteDevice: concreteDeviceRepository,
            deviceGroup: deviceGroupRepository,
            instantiableBrowserDevice: instantiableBrowserDeviceRepository,
            instantiableCloudDevice: instantiableCloudDeviceRepository,
            peerconnection: peerconnectionRepository,
        };
    }
}
exports.AppDataSource = new ApplicationDataSource(config_1.dataSourceConfig);
exports.repositories = exports.AppDataSource.repositories;
exports.dataSource = exports.AppDataSource.dataSource;
//# sourceMappingURL=dataSource.js.map