"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.DeviceGroupRepository = void 0;
const globals_1 = require("../../../globals");
const model_1 = require("../../model");
const service_common_1 = require("@crosslab/service-common");
const urlFromId_1 = require("../../../methods/urlFromId");
class DeviceGroupRepository extends service_common_1.AbstractRepository {
    constructor() {
        super('Device Group');
        this.dependencies = {};
    }
    dependenciesMet() {
        if (!this.dependencies.deviceOverview)
            return false;
        return true;
    }
    initialize(entityManager) {
        this.repository = entityManager.getRepository(model_1.DeviceGroupModel);
    }
    async create(data) {
        const model = await super.create(data);
        model.type = 'group';
        return model;
    }
    async write(model, data) {
        if (!this.isInitialized())
            this.throwUninitializedRepositoryError();
        await this.dependencies.deviceOverview.write(model, data);
        if (data.devices)
            model.devices = data.devices;
    }
    async format(model, options) {
        if (!this.isInitialized())
            this.throwUninitializedRepositoryError();
        const devices = options?.flat_group
            ? await this.resolveDeviceGroup({ ...model, url: (0, urlFromId_1.deviceUrlFromId)(model.uuid) }, [], { execute_for: options.execute_for })
            : model.devices;
        return {
            ...(await this.dependencies.deviceOverview.format(model)),
            type: 'group',
            devices: devices.filter((value, index, array) => array.findIndex((device) => device.url === value.url) === index),
        };
    }
    async resolveDeviceGroup(deviceGroup, alreadyResolved, options) {
        alreadyResolved.push(deviceGroup.url);
        const devices = [];
        for (const deviceReference of deviceGroup.devices) {
            const device = await this.resolveDeviceReference(deviceReference, options);
            if (!device)
                continue;
            if (device.type === 'group') {
                if (!alreadyResolved.includes(device.url))
                    devices.push(...(await this.resolveDeviceGroup(device, alreadyResolved)));
            }
            else {
                devices.push(device);
            }
        }
        return devices;
    }
    async resolveDeviceReference(deviceReference, options) {
        try {
            return await globals_1.apiClient.getDevice(deviceReference.url, options);
        }
        catch (error) {
            service_common_1.logger.log('error', 'An error occured while trying to resolve a device reference', { data: { error } });
        }
        return undefined;
    }
}
exports.DeviceGroupRepository = DeviceGroupRepository;
//# sourceMappingURL=deviceGroup.js.map