"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.InstantiableCloudDeviceRepository = void 0;
const model_1 = require("../../model");
const service_common_1 = require("@crosslab/service-common");
class InstantiableCloudDeviceRepository extends service_common_1.AbstractRepository {
    constructor() {
        super('Instantiable Cloud Device');
        this.dependencies = {};
    }
    dependenciesMet() {
        if (!this.dependencies.deviceOverview)
            return false;
        return true;
    }
    initialize(entityManager) {
        this.repository = entityManager.getRepository(model_1.InstantiableCloudDeviceModel);
    }
    async create(data) {
        const model = await super.create(data);
        model.type = 'cloud instantiable';
        return model;
    }
    async write(model, data) {
        if (!this.isInitialized())
            this.throwUninitializedRepositoryError();
        await this.dependencies.deviceOverview.write(model, data);
        if (data.instantiateUrl)
            model.instantiateUrl = data.instantiateUrl;
        if (data.services)
            model.services = data.services;
    }
    async format(model) {
        if (!this.isInitialized())
            this.throwUninitializedRepositoryError();
        return {
            ...(await this.dependencies.deviceOverview.format(model)),
            type: 'cloud instantiable',
            instantiateUrl: model.instantiateUrl,
            services: model.services ?? undefined,
        };
    }
}
exports.InstantiableCloudDeviceRepository = InstantiableCloudDeviceRepository;
//# sourceMappingURL=instantiableCloudDevice.js.map