#!/usr/bin/env node
"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const config_1 = require("./config");
const dataSource_1 = require("./database/dataSource");
const index_1 = require("./generated/index");
const types_1 = require("./generated/types");
const globals_1 = require("./globals");
const callbacks_1 = require("./operations/callbacks");
const devices_1 = require("./operations/devices");
const service_common_1 = require("@crosslab/service-common");
const ws_1 = __importDefault(require("ws"));
async function startDeviceService() {
    await dataSource_1.AppDataSource.initialize(config_1.dataSourceConfig);
    globals_1.apiClient.accessToken = config_1.config.API_TOKEN;
    index_1.app.get('/device/status', (_req, res) => {
        res.send({ status: 'ok' });
    });
    index_1.app.initService({
        security: {
            JWT: (0, service_common_1.JWTVerify)(config_1.config, types_1.isUserTypeJWT, service_common_1.parseJwtFromAuthorizationHeader),
        },
        preHandlers: [service_common_1.requestIdHandling, service_common_1.logHandling],
        postHandlers: [callbacks_1.callbackHandling, service_common_1.missingRouteHandling],
        errorHandler: service_common_1.errorHandler,
    });
    const wsServer = new ws_1.default.Server({ noServer: true });
    index_1.app.wsListeners = new Map();
    index_1.app.ws = (path, listener) => index_1.app.wsListeners.set(path, listener);
    (0, devices_1.websocketHandling)(index_1.app);
    const server = index_1.app.listen(config_1.config.PORT);
    server.on('upgrade', async (request, socket, head) => {
        const listener = index_1.app.wsListeners.get(request.url ?? '');
        if (listener) {
            wsServer.handleUpgrade(request, socket, head, (webSocket) => listener(webSocket));
        }
    });
    service_common_1.logger.log('info', 'Device Service started successfully');
}
/* istanbul ignore if */
if (require.main === module) {
    startDeviceService();
}
//# sourceMappingURL=index.js.map