"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.sendStatusChangedCallback = exports.sendClosedCallback = exports.sendChangedCallback = exports.statusChangedCallbacks = exports.closedCallbacks = exports.changedCallbacks = exports.callbackUrl = void 0;
const config_1 = require("../config");
const dataSource_1 = require("../database/dataSource");
const urlFromId_1 = require("./urlFromId");
const service_common_1 = require("@crosslab/service-common");
const node_fetch_1 = __importDefault(require("node-fetch"));
exports.callbackUrl = (config_1.config.BASE_URL + '/callbacks/device').replace('//callbacks', '/callbacks');
exports.changedCallbacks = new Map();
exports.closedCallbacks = new Map();
exports.statusChangedCallbacks = new Map();
/**
 * This function sends a 'device-changed' callback.
 * @param device The device for which to send the callback.
 */
async function sendChangedCallback(device) {
    const urls = exports.changedCallbacks.get(device.uuid) ?? [];
    for (const url of urls) {
        service_common_1.logger.log('info', `Sending changed-callback for device '${(0, urlFromId_1.deviceUrlFromId)(device.uuid)}' to '${url}'`);
        const callback = {
            callbackType: 'event',
            eventType: 'device-changed',
            device: await dataSource_1.repositories.device.format(device),
        };
        // TODO: proper error handling
        try {
            const res = await (0, node_fetch_1.default)(url, {
                method: 'POST',
                body: JSON.stringify(callback),
                headers: [['Content-Type', 'application/json']],
            });
            if (res.status === 410) {
                const changedCallbackURLs = exports.changedCallbacks.get(device.uuid);
                exports.changedCallbacks.set(device.uuid, changedCallbackURLs?.filter((cb_url) => cb_url != url));
            }
        }
        catch (error) {
            service_common_1.logger.log('error', 'An error occurred while sending a changed-callback', {
                data: { error, device: (0, urlFromId_1.deviceUrlFromId)(device.uuid), url },
            });
        }
    }
}
exports.sendChangedCallback = sendChangedCallback;
/**
 * This function sends a 'peerconnection-closed' callback.
 * @param peerconnection The peerconnection for which to send the callback.
 */
async function sendClosedCallback(peerconnection) {
    const urls = exports.closedCallbacks.get(peerconnection.uuid) ?? [];
    for (const url of urls) {
        service_common_1.logger.log('info', `Sending closed-callback for peerconnection '${(0, urlFromId_1.peerconnectionUrlFromId)(peerconnection.uuid)}' to '${url}'`);
        const callback = {
            callbackType: 'event',
            eventType: 'peerconnection-closed',
            peerconnection: await dataSource_1.repositories.peerconnection.format(peerconnection),
        };
        // TODO: proper error handling
        try {
            const res = await (0, node_fetch_1.default)(url, {
                method: 'POST',
                body: JSON.stringify(callback),
                headers: [['Content-Type', 'application/json']],
            });
            if (res.status === 410) {
                const closedCallbackURLs = exports.closedCallbacks.get(peerconnection.uuid);
                exports.closedCallbacks.set(peerconnection.uuid, closedCallbackURLs?.filter((cb_url) => cb_url != url));
            }
        }
        catch (error) {
            service_common_1.logger.log('error', 'An error occurred while sending a closed-callback', {
                data: {
                    error,
                    peerconnection: (0, urlFromId_1.peerconnectionUrlFromId)(peerconnection.uuid),
                    url,
                },
            });
        }
    }
}
exports.sendClosedCallback = sendClosedCallback;
/**
 * This function sends a 'peerconnection-status-changed' callback.
 * @param peerconnection The peerconnection for which to send the callback.
 */
async function sendStatusChangedCallback(peerconnection) {
    const urls = exports.statusChangedCallbacks.get(peerconnection.uuid) ?? [];
    for (const url of urls) {
        service_common_1.logger.log('info', `Sending status-changed-callback for peerconnection '${(0, urlFromId_1.peerconnectionUrlFromId)(peerconnection.uuid)}' to '${url}'`);
        const callback = {
            callbackType: 'event',
            eventType: 'peerconnection-status-changed',
            peerconnection: await dataSource_1.repositories.peerconnection.format(peerconnection),
        };
        // TODO: proper error handling
        try {
            const res = await (0, node_fetch_1.default)(url, {
                method: 'POST',
                body: JSON.stringify(callback),
                headers: [['Content-Type', 'application/json']],
            });
            if (res.status === 410) {
                const statusCallbackURLs = exports.statusChangedCallbacks.get(peerconnection.uuid);
                exports.statusChangedCallbacks.set(peerconnection.uuid, statusCallbackURLs?.filter((cb_url) => cb_url != url));
            }
        }
        catch (error) {
            service_common_1.logger.log('error', 'An error occurred while sending a status-changed-callback', {
                data: {
                    error,
                    peerconnection: (0, urlFromId_1.peerconnectionUrlFromId)(peerconnection.uuid),
                    url,
                },
            });
        }
    }
}
exports.sendStatusChangedCallback = sendStatusChangedCallback;
//# sourceMappingURL=callbacks.js.map