"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.simpleQueueManager = void 0;
const service_common_1 = require("@crosslab/service-common");
const async_mutex_1 = require("async-mutex");
const queue_1 = __importDefault(require("queue"));
class SimpleQueueManager {
    constructor() {
        this.mutex = new async_mutex_1.Mutex();
        this.queueMap = new Map();
    }
    async addToQueue(id, handler) {
        const release = await this.mutex.acquire();
        try {
            const queue = this.queueMap.get(id) ??
                new queue_1.default({
                    concurrency: 1,
                });
            queue.push(async () => {
                await handler();
            });
            queue.start(async (error) => {
                if (error)
                    service_common_1.logger.log('error', `An error occurred while processing a job in the queue for ${id}`);
                else {
                    const internalRelease = await this.mutex.acquire();
                    try {
                        if (queue.length === 0)
                            this.queueMap.delete(id);
                    }
                    finally {
                        internalRelease();
                    }
                }
            });
            if (!this.queueMap.has(id))
                this.queueMap.set(id, queue);
        }
        finally {
            release();
        }
    }
}
exports.simpleQueueManager = new SimpleQueueManager();
//# sourceMappingURL=queueManager.js.map