"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.SignalingQueue = void 0;
const globals_1 = require("../../globals");
const service_common_1 = require("@crosslab/service-common");
const queue_1 = __importDefault(require("queue"));
class SignalingQueue {
    constructor(peerconnectionUrl, deviceUrl) {
        this._state = 'new';
        this._isStopped = false;
        this.deviceUrl = deviceUrl;
        this.peerconnectionUrl = peerconnectionUrl;
        this.queue = new queue_1.default({
            concurrency: 1,
        });
        this._onClose = () => {
            this.queue.end();
        };
    }
    get state() {
        return this._state;
    }
    get isStopped() {
        return this._isStopped;
    }
    get onClose() {
        return this._onClose;
    }
    set onClose(onClose) {
        this._onClose = () => {
            this.queue.end();
            if (onClose)
                onClose();
        };
    }
    add(signalingMessage) {
        this.queue.push(async () => {
            await this.sendSignalingMessage(signalingMessage);
            if (signalingMessage.messageType === 'command') {
                switch (signalingMessage.command) {
                    case 'createPeerconnection':
                        this._state = 'peerconnection-created';
                        break;
                    case 'closePeerconnection':
                        this._state = 'peerconnection-closed';
                        this._onClose();
                        break;
                }
            }
        });
        if ((this.state === 'peerconnection-created' || this.state === 'started') &&
            !this._isStopped)
            this.start();
    }
    async sendSignalingMessage(signalingMessage) {
        try {
            await globals_1.apiClient.sendSignalingMessage(this.deviceUrl, signalingMessage, this.peerconnectionUrl);
        }
        catch (error) {
            service_common_1.logger.log('error', 'An error occurred while trying to send a signaling message', {
                data: {
                    error,
                    message: signalingMessage,
                    targetDevice: this.deviceUrl,
                    peerconnection: this.peerconnectionUrl,
                },
            });
        }
    }
    start() {
        this.queue.start((error) => {
            if (error)
                service_common_1.logger.log('error', 'An error occurred while processing a signaling message', {
                    data: {
                        error,
                        targetDevice: this.deviceUrl,
                        peerconnection: this.peerconnectionUrl,
                    },
                });
        });
        this._isStopped = false;
        if (this._state === 'new')
            this._state = 'started';
    }
    stop() {
        this.queue.stop();
        this._isStopped = true;
    }
    isEmpty() {
        return this.queue.length === 0;
    }
}
exports.SignalingQueue = SignalingQueue;
//# sourceMappingURL=signalingQueue.js.map