"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.handleDeviceChangedEventCallback = void 0;
const dataSource_1 = require("../../../database/dataSource");
const globals_1 = require("../../../globals");
const signalingQueueManager_1 = require("../../../methods/signaling/signalingQueueManager");
/**
 * This function handles an incoming "device-changed" event callback.
 * @param callback The incoming "device-changed" callback to be handled.
 * @returns The status code for the response to the incoming callback.
 */
async function handleDeviceChangedEventCallback(callback) {
    console.log(callback.device.type);
    switch (callback.device.type) {
        case 'device':
            return await handleConcreteDevice(callback.device);
        default:
            return 410;
    }
}
exports.handleDeviceChangedEventCallback = handleDeviceChangedEventCallback;
async function handleConcreteDevice(concreteDevice) {
    const pendingConnections = (await dataSource_1.repositories.peerconnection.find({
        where: {
            status: 'new',
        },
    })).filter((peerconnection) => peerconnection.deviceA.url === concreteDevice.url ||
        peerconnection.deviceB.url === concreteDevice.url);
    for (const pendingConnection of pendingConnections) {
        const deviceA = await globals_1.apiClient.getDevice(pendingConnection.deviceA.url);
        const deviceB = await globals_1.apiClient.getDevice(pendingConnection.deviceB.url);
        if (deviceA.connected && deviceB.connected) {
            clearTimeout(globals_1.timeoutMap.get(pendingConnection.uuid));
            signalingQueueManager_1.signalingQueueManager.startSignalingQueues(pendingConnection.uuid);
            globals_1.timeoutMap.delete(pendingConnection.uuid);
        }
    }
    return pendingConnections.length === 0 ? 410 : 200;
}
//# sourceMappingURL=deviceChanged.js.map