"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.handleEventCallback = void 0;
const types_1 = require("../../../generated/types");
const deviceChanged_1 = require("./deviceChanged");
const service_common_1 = require("@crosslab/service-common");
/**
 * This function handles an incoming event callback.
 * @param callback The incoming event callback to be handled.
 * @throws {MalformedBodyError} Thrown if the callback is malformed.
 * @throws {InvalidValueError} Thrown if the type of the event callback is unknown.
 * @returns The status code of the callback response.
 */
async function handleEventCallback(callback) {
    switch (callback.eventType) {
        case 'device-changed':
            if (!(0, types_1.isDeviceChangedEventCallback)(callback))
                throw new service_common_1.MalformedBodyError('Body of request is not a valid device-changed event callback', 400);
            return await (0, deviceChanged_1.handleDeviceChangedEventCallback)(callback);
        default:
            throw new service_common_1.InvalidValueError(`Event-callbacks of type '${callback.eventType}' are not supported`, 400);
    }
}
exports.handleEventCallback = handleEventCallback;
//# sourceMappingURL=index.js.map