"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.deleteDevicesByDeviceIdAvailability = void 0;
const service_common_1 = require("@crosslab/service-common");
const dataSource_1 = require("../../../../database/dataSource");
const permission_1 = require("../../../../methods/permission");
/**
 * This function implements the functionality for handling DELETE requests on /devices/{device_id}/availability endpoint.
 * @param parameters The parameters of the request.
 * @param user The user submitting the request.
 * @throws {MissingEntityError} Thrown if device is not found in the database.
 */
const deleteDevicesByDeviceIdAvailability = async (parameters, user) => {
    service_common_1.logger.log('info', 'deleteDevicesByDeviceIdAvailability called');
    const deviceModel = await dataSource_1.repositories.device.findOneOrFail({
        where: { uuid: parameters.device_id },
    });
    if (deviceModel.type !== 'device')
        throw new service_common_1.ImpossibleOperationError("Availability rules can only be deleted for devices of type 'device'", 400);
    if (!(0, permission_1.checkPermission)('write', deviceModel, user.JWT))
        throw new service_common_1.DeviceOwnershipError();
    deviceModel.availabilityRules = [];
    await dataSource_1.repositories.device.save(deviceModel);
    service_common_1.logger.log('info', 'deleteDevicesByDeviceIdAvailability succeeded');
    return {
        status: 204,
    };
};
exports.deleteDevicesByDeviceIdAvailability = deleteDevicesByDeviceIdAvailability;
//# sourceMappingURL=delete.js.map