"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.getDevicesByDeviceIdAvailability = void 0;
const service_common_1 = require("@crosslab/service-common");
const dataSource_1 = require("../../../../database/dataSource");
const permission_1 = require("../../../../methods/permission");
const availability_1 = require("../../../../methods/availability");
const globals_1 = require("../../../../globals");
/**
 * This function implements the functionality for handling GET requests on /devices/{device_id}/availability endpoint.
 * @param parameters The parameters of the request.
 * @param user The user submitting the request.
 * @throws {MissingEntityError} Thrown if device is not found in the database.
 */
const getDevicesByDeviceIdAvailability = async (parameters, user) => {
    service_common_1.logger.log('info', 'getDevicesByDeviceIdAvailability called');
    const deviceModel = await dataSource_1.repositories.device.findOneOrFail({
        where: { uuid: parameters.device_id },
    });
    if (deviceModel.type !== 'device')
        throw new service_common_1.ImpossibleOperationError("Availability can only be retrieved for devices of type 'device'");
    if (!(0, permission_1.checkPermission)('read', deviceModel, user.JWT))
        throw new service_common_1.DeviceOwnershipError();
    const startTime = parameters.startTime
        ? Date.parse(parameters.startTime)
        : Date.now();
    const endTime = (parameters.startTime ? Date.parse(parameters.startTime) : startTime) + globals_1.WEEK;
    const availability = (0, availability_1.calculateAvailability)(deviceModel.availabilityRules, startTime, endTime);
    service_common_1.logger.log('info', 'getDevicesByDeviceIdAvailability succeeded');
    return {
        status: 200,
        body: availability,
    };
};
exports.getDevicesByDeviceIdAvailability = getDevicesByDeviceIdAvailability;
//# sourceMappingURL=get.js.map