"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.postDevicesByDeviceIdAvailability = void 0;
const dataSource_1 = require("../../../../database/dataSource");
const availability_1 = require("../../../../methods/availability");
const callbacks_1 = require("../../../../methods/callbacks");
const service_common_1 = require("@crosslab/service-common");
const permission_1 = require("../../../../methods/permission");
const globals_1 = require("../../../../globals");
/**
 * This function implements the functionality for handling POST requests on /devices/{device_id}/availability endpoint.
 * @param parameters The parameters of the request.
 * @param body The body of the request.
 * @param user The user submitting the request.
 * @throws {MissingEntityError} Thrown if device is not found in the database.
 */
const postDevicesByDeviceIdAvailability = async (parameters, body, user) => {
    service_common_1.logger.log('info', 'postDevicesByDeviceIdAvailability called');
    const deviceModel = await dataSource_1.repositories.device.findOneOrFail({
        where: { uuid: parameters.device_id },
    });
    if (deviceModel.type !== 'device') {
        throw new service_common_1.ImpossibleOperationError(`Can only update the availability for a device of type 'device', not for type '${deviceModel.type}'`, 400);
    }
    if (!(0, permission_1.checkPermission)('write', deviceModel, user.JWT))
        throw new service_common_1.DeviceOwnershipError();
    deviceModel.availabilityRules ??= [];
    deviceModel.availabilityRules.push(...(body ?? []));
    const start = Date.now();
    const end = start + globals_1.WEEK;
    deviceModel.announcedAvailability = (0, availability_1.calculateAvailability)(deviceModel.availabilityRules, start, end);
    await dataSource_1.repositories.device.save(deviceModel);
    await (0, callbacks_1.sendChangedCallback)(deviceModel);
    service_common_1.logger.log('info', 'postDevicesByDeviceIdAvailability succeeded');
    return {
        status: 200,
        body: deviceModel.announcedAvailability,
    };
};
exports.postDevicesByDeviceIdAvailability = postDevicesByDeviceIdAvailability;
//# sourceMappingURL=post.js.map