"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.deleteDevicesByDeviceId = void 0;
const dataSource_1 = require("../../../database/dataSource");
const service_common_1 = require("@crosslab/service-common");
const permission_1 = require("../../../methods/permission");
/**
 * This function implements the functionality for handling DELETE requests on /devices/{device_id} endpoint.
 * @param parameters The parameters of the request.
 * @param _user The user submitting the request.
 * @throws {MissingEntityError} Thrown if device is not found in the database.
 */
const deleteDevicesByDeviceId = async (parameters, user) => {
    service_common_1.logger.log('info', 'deleteDevicesByDeviceId called');
    const deviceModel = await dataSource_1.repositories.device.findOneOrFail({
        where: { uuid: parameters.device_id },
    });
    if (!(0, permission_1.checkPermission)('delete', deviceModel, user.JWT))
        throw new service_common_1.DeviceOwnershipError();
    await dataSource_1.repositories.device.remove(deviceModel);
    service_common_1.logger.log('info', 'deleteDevicesByDeviceId succeeded');
    return {
        status: 204,
    };
};
exports.deleteDevicesByDeviceId = deleteDevicesByDeviceId;
//# sourceMappingURL=delete.js.map