"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.getDevicesByDeviceId = void 0;
const dataSource_1 = require("../../../database/dataSource");
const service_common_1 = require("@crosslab/service-common");
const permission_1 = require("../../../methods/permission");
const config_1 = require("../../../config");
const types_1 = require("../../../generated/types");
function validatePayload(output) {
    return (0, types_1.isUserType)(output, 'JWT');
}
const validateExecuteFor = (0, service_common_1.JWTVerify)(config_1.config, validatePayload, (input) => input);
/**
 * This function implements the functionality for handling GET requests on /devices/{device_id} endpoint.
 * @param parameters The parameters of the request.
 * @param user The user submitting the request.
 * @throws {MissingEntityError} Thrown if device is not found in the database.
 */
const getDevicesByDeviceId = async (parameters, user) => {
    service_common_1.logger.log('info', 'getDevicesByDeviceId called');
    const executeForUser = parameters.execute_for
        ? await validateExecuteFor(parameters.execute_for, [])
        : undefined;
    const deviceModel = await dataSource_1.repositories.device.findOneOrFail({
        where: { uuid: parameters.device_id },
    });
    if (!(0, permission_1.checkPermission)('read', deviceModel, user.JWT))
        throw new service_common_1.DeviceOwnershipError();
    if (executeForUser)
        if (!(0, permission_1.checkPermission)('read', deviceModel, executeForUser))
            throw new service_common_1.DeviceOwnershipError();
    service_common_1.logger.log('info', 'getDevicesByDeviceId succeeded');
    return {
        status: 200,
        body: await dataSource_1.repositories.device.format(deviceModel, {
            flat_group: parameters.flat_group,
            execute_for: parameters.execute_for ?? user.JWT.jwt,
        }),
    };
};
exports.getDevicesByDeviceId = getDevicesByDeviceId;
//# sourceMappingURL=get.js.map