"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.patchDevicesByDeviceId = void 0;
const dataSource_1 = require("../../../database/dataSource");
const callbacks_1 = require("../../../methods/callbacks");
const permission_1 = require("../../../methods/permission");
const urlFromId_1 = require("../../../methods/urlFromId");
const service_common_1 = require("@crosslab/service-common");
/**
 * This function implements the functionality for handling PATCH requests on /devices/{device_id} endpoint.
 * @param parameters The parameters of the request.
 * @param body The body of the request.
 * @param _user The user submitting the request.
 * @throws {MissingEntityError} Thrown if device is not found in the database.
 * @throws {InvalidChangeError} Thrown if client tries to update the type of the device.
 */
const patchDevicesByDeviceId = async (parameters, body, user) => {
    service_common_1.logger.log('info', 'patchDevicesByDeviceId called');
    const deviceModel = await dataSource_1.repositories.device.findOneOrFail({
        where: { uuid: parameters.device_id },
    });
    if (!(0, permission_1.checkPermission)('write', deviceModel, user.JWT))
        throw new service_common_1.DeviceOwnershipError();
    await dataSource_1.repositories.device.write(deviceModel, body ?? { type: deviceModel.type });
    await dataSource_1.repositories.device.save(deviceModel);
    await (0, callbacks_1.sendChangedCallback)(deviceModel);
    if (parameters.changedUrl) {
        service_common_1.logger.log('info', `registering changed-callback for device '${(0, urlFromId_1.deviceUrlFromId)(deviceModel.uuid)}' to '${parameters.changedUrl}'`);
        const changedCallbackURLs = callbacks_1.changedCallbacks.get(deviceModel.uuid) ?? [];
        changedCallbackURLs.push(parameters.changedUrl);
        callbacks_1.changedCallbacks.set(deviceModel.uuid, changedCallbackURLs);
    }
    service_common_1.logger.log('info', 'patchDevicesByDeviceId succeeded');
    return {
        status: 200,
        body: await dataSource_1.repositories.device.format(deviceModel),
    };
};
exports.patchDevicesByDeviceId = patchDevicesByDeviceId;
//# sourceMappingURL=patch.js.map