"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.postDevicesByDeviceIdWebsocket = void 0;
const dataSource_1 = require("../../../../database/dataSource");
const urlFromId_1 = require("../../../../methods/urlFromId");
const service_common_1 = require("@crosslab/service-common");
const crypto_1 = require("crypto");
/**
 * This function implements the functionality for handling POST requests on /devices/{device_id}/token endpoint.
 * @param parameters The parameters of the request.
 * @param _user The user submitting the request.
 * @throws {_MissingEntityError} Thrown if device is not found in the database.
 */
const postDevicesByDeviceIdWebsocket = async (parameters, _user) => {
    service_common_1.logger.log('info', 'postDevicesByDeviceIdWebsocket called');
    const deviceModel = await dataSource_1.repositories.device.findOneOrFail({
        where: {
            uuid: parameters.device_id,
        },
    });
    if (deviceModel.type !== 'device')
        throw new service_common_1.ImpossibleOperationError("A websocket token may only be requested for a device of type 'device'", 400);
    deviceModel.token = (0, crypto_1.randomUUID)();
    await dataSource_1.repositories.device.save(deviceModel);
    setTimeout(async () => {
        service_common_1.logger.log('info', `trying to delete websocket token of device '${(0, urlFromId_1.deviceUrlFromId)(parameters.device_id)}'`);
        const newDeviceModel = await dataSource_1.repositories.device.findOne({
            where: {
                uuid: parameters.device_id,
            },
        });
        if (!newDeviceModel) {
            service_common_1.logger.error('error', `device '${(0, urlFromId_1.deviceUrlFromId)(parameters.device_id)}' does not exist`);
            return;
        }
        if (newDeviceModel.type !== 'device') {
            service_common_1.logger.error('error', `device '${(0, urlFromId_1.deviceUrlFromId)(parameters.device_id)}' has type '${newDeviceModel.type}' instead of 'device'`);
            return;
        }
        newDeviceModel.token = undefined;
        await dataSource_1.repositories.device.save(newDeviceModel);
    }, 300000);
    service_common_1.logger.log('info', 'postDevicesByDeviceIdWebsocket succeeded');
    return {
        status: 200,
        body: deviceModel.token,
    };
};
exports.postDevicesByDeviceIdWebsocket = postDevicesByDeviceIdWebsocket;
//# sourceMappingURL=post.js.map