"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.postDevices = void 0;
const dataSource_1 = require("../../database/dataSource");
const callbacks_1 = require("../../methods/callbacks");
const urlFromId_1 = require("../../methods/urlFromId");
const service_common_1 = require("@crosslab/service-common");
/**
 * This function implements the functionality for handling POST requests on /devices endpoint.
 * @param parameters The parameters of the request.
 * @param body The body of the request.
 * @param user The user submitting the request.
 */
const postDevices = async (parameters, body, user) => {
    service_common_1.logger.log('info', 'postDevices called');
    if (!body.name)
        throw new service_common_1.MalformedBodyError("Property 'name' is required and must not be empty", 400);
    const deviceModel = await dataSource_1.repositories.device.create(body);
    deviceModel.owner = user.JWT.url;
    await dataSource_1.repositories.device.save(deviceModel);
    if (parameters.changedUrl) {
        service_common_1.logger.log('info', `registering changed-callback for device '${(0, urlFromId_1.deviceUrlFromId)(deviceModel.uuid)}' to '${parameters.changedUrl}'`);
        callbacks_1.changedCallbacks.set(deviceModel.uuid, [parameters.changedUrl]);
    }
    service_common_1.logger.log('info', 'postDevices succeeded');
    return {
        status: 201,
        body: await dataSource_1.repositories.device.format(deviceModel),
    };
};
exports.postDevices = postDevices;
//# sourceMappingURL=post.js.map