"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.deletePeerconnectionsByPeerconnectionId = exports.deleteOnClose = void 0;
const dataSource_1 = require("../../../database/dataSource");
const signalingQueueManager_1 = require("../../../methods/signaling/signalingQueueManager");
const urlFromId_1 = require("../../../methods/urlFromId");
const service_common_1 = require("@crosslab/service-common");
exports.deleteOnClose = new Set();
/**
 * This function implements the functionality for handling DELETE requests on /peerconnection/{peerconnection_id} endpoint.
 * @param parameters The parameters of the request.
 * @param _user The user submitting the request.
 */
const deletePeerconnectionsByPeerconnectionId = async (parameters, _user) => {
    service_common_1.logger.log('info', 'deletePeerconnectionsByPeerconnectionId called');
    const peerconnectionModel = await dataSource_1.repositories.peerconnection.findOneOrFail({
        where: { uuid: parameters.peerconnection_id },
    });
    if (peerconnectionModel.deviceA.status === 'closed' &&
        peerconnectionModel.deviceB.status === 'closed') {
        signalingQueueManager_1.signalingQueueManager.setOnCloseHandler(peerconnectionModel.uuid, async () => {
            try {
                await dataSource_1.repositories.peerconnection.remove(peerconnectionModel);
            }
            catch (error) {
                service_common_1.logger.log('error', `Something went wrong while trying to delete peerconnection '${(0, urlFromId_1.peerconnectionUrlFromId)(peerconnectionModel.uuid)}'`, { data: { error } });
            }
        });
        signalingQueueManager_1.signalingQueueManager.closeSignalingQueues(peerconnectionModel.uuid);
    }
    else {
        exports.deleteOnClose.add(peerconnectionModel.uuid);
        signalingQueueManager_1.signalingQueueManager.closeSignalingQueues(peerconnectionModel.uuid);
    }
    service_common_1.logger.log('info', 'deletePeerconnectionsByPeerconnectionId succeeded');
    return {
        status: 202,
    };
};
exports.deletePeerconnectionsByPeerconnectionId = deletePeerconnectionsByPeerconnectionId;
//# sourceMappingURL=delete.js.map